# How to write a parser plugin

Writing a parser plugin is different depending on which parser you're writing a 
plugin for. Parsers that support plugins are:

* bencode
* cookie
* czip (Compound zip files)
* esedb
* olecf
* plist
* [sqlite](How-to-write-a-SQLite-plugin.md)
* [syslog](How-to-write-a-Syslog-plugin.md)
* winreg
